/* This is a fake file (it is never used when compiling) whose only
 * purpose is to serve as a place holder to put the translatable strings
 * of the Scheme game rules (that is those *.scm files) so xgettext can
 * find them.
 *
 * Ideally xgettext should look inside of the *.scm, but xgettext has
 * big problems whith scheme syntax, it seems to understand only C :)
 */

char only_a_place_holder[]={ 
N_("   "),
N_(" of "),
N_("'s"),
N_("Base Card:  "),
N_("Base Card:  Ace"),
N_("Base Card:  Jack"),
N_("Base Card:  King"),
N_("Base Card:  Queen"),
N_("Consider moving something into an empty slot"),
N_("Consistency is key"),
N_("Deal a card"),
N_("Deal a card from the deck"),
N_("Deal a new card from the deck"),
N_("Deal another card"),
N_("Deal another round"),
N_("Deal the cards"),
N_("Fishing wire makes bad dental floss"),
N_("Have you read the help file?"),
N_("I could sure use a backrub right about now..."),
N_("If you're ever lost and alone in the woods, hug a tree"),
N_("Just because a crosswalk looks like a hopscotch board doesn't mean it is one"),
N_("Look both ways before you cross the street"),
N_("Monitors won't give you Vitamin D -- but sunlight will..."),
N_("Move card from Waste"),
N_("Move waste back to stock"),
N_("Never blow in a dog's ear"),
N_("Odessa is a better game.  Really."),
N_("Place something on empty slot"),
N_("Please fill in empty pile first."),
N_("Redeals left:  "),
N_("Remove the "),
N_("Reserve left:  "),
N_("Return cards to Stock"),
N_("Stock left:  "),
N_("Stock left:  0"),
N_("Three card deals"),
N_("Tourniquets are not recommended unless in the direst emergency"),
N_("Try moving cards down from the foundation"),
N_("Try rearranging the cards"),
N_("Unknown color"),
N_("Unknown suit"),
N_("Unknown value"),
N_("When without a stapler, a staple and a ruler will work"),
N_("ace"),
N_("aces"),
N_("an empty Foundation"),
N_("an empty Foundation pile"),
N_("an empty Tableau pile"),
N_("an empty Tableau slot"),
N_("an empty bottom slot"),
N_("an empty corner slot"),
N_("an empty left slot"),
N_("an empty right slot"),
N_("an empty slot"),
N_("an empty slot on tableau"),
N_("an empty top slot"),
N_("appropriate Foundation pile"),
N_("black joker"),
N_("borp"),
N_("clubs"),
N_("diamonds"),
N_("eight"),
N_("empty slot on foundation"),
N_("empty space on tableau"),
N_("five"),
N_("four"),
N_("hearts"),
N_("itself"),
N_("jack"),
N_("jacks"),
N_("king"),
N_("kings"),
N_("nine"),
N_("off the board"),
N_("queen"),
N_("queens"),
N_("seven"),
N_("six"),
N_("something"),
N_("spades"),
N_("ten"),
N_("the appropriate Foundation pile"),
N_("three"),
N_("to an empty foundation"),
N_("two"),
}
